@@ -27,7 +27,7 @@
 #include "panel-menu-bar.h"
 
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "panel-util.h"
 #include "panel-action-button.h"
@@ -42,7 +42,7 @@
 
 #define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR, PanelMenuBarPrivate))
 
-#define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_DISTRIBUTION_SUB)
+#define MENU_FLAGS (MAIN_MENU_SYSTEM)
 
 struct _PanelMenuBarPrivate {
 	AppletInfo            *info;
@@ -147,7 +147,7 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 
 	panel_recent_append_documents_menu (menubar->priv->actions_menu);
 
-	if (panel_is_program_in_path ("gnome-panel-screenshot")) {
+	if (panel_is_program_in_path ("gnome-screenshot")) {
 		item = gtk_separator_menu_item_new ();
 		gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
 		gtk_widget_show (item);
