@@ -35,11 +35,15 @@
 #include <dirent.h>
 #include <errno.h>
 #include <sys/types.h>
+
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-desktop-item.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnome/gnome-exec.h>
+#include <libgnome/gnome-util.h>
+#include <libgnomeui/gnome-entry.h>
+#include <libgnomeui/gnome-url.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <gconf/gconf-client.h>
 
@@ -460,7 +464,7 @@ panel_run_dialog_append_file_utf8 (PanelRunDialog *dialog,
 	char       *quoted, *temp;
 	
 	/* Don't allow filenames beginning with '-' */
-	if (!file || file[0] == '-')
+	if (!file || !file[0] || file[0] == '-')
 		return;
 	
 	quoted = quote_string (file);
@@ -555,7 +559,7 @@ panel_run_dialog_find_command_icon_idle (PanelRunDialog *dialog)
 	gboolean      fuzzy;
 	
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->program_list));
-	path = gtk_tree_path_new_root ();
+	path = gtk_tree_path_new_first ();
 	text = gtk_entry_get_text (GTK_ENTRY (dialog->gtk_entry));
 	found_icon = NULL;
 	found_name = NULL;
@@ -1368,7 +1372,7 @@ entry_drag_data_received (GtkEditable      *entry,
 	}
 
 	for (i = 0; uris [i]; i++) {
-		if (!uris [i] || !uris [i])
+		if (!uris [i] || !uris [i][0])
 			continue;
 		
 		file = gnome_vfs_get_local_path_from_uri (uris [i]);
